#
# spec file for package lapack
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without tmg

%if 0%{?suse_version} > 1500
%define a_x _%{_arch}
%endif

Name:           lapack
Version:        3.9.0
Release:        150000.4.13.2
Summary:        Linear Algebra Package
License:        BSD-3-Clause
Group:          Development/Libraries/Parallel
URL:            https://www.netlib.org/lapack/
Source0:        https://github.com/Reference-LAPACK/lapack/archive/v%{version}.tar.gz#/lapack-%{version}.tar.gz
Source98:       lapack.rpmlintrc
Source99:       baselibs.conf
Patch1:         lapack-3.2.2.patch
# PATCH-FIX-UPSTREAM -- https://github.com/Reference-LAPACK/lapack/commit/489a2884c22e.patch
Patch2:         Fix-MinGW-build-error.patch
# PATCH-FIX-UPSTREAM -- https://github.com/Reference-LAPACK/lapack/commit/d168b4d2ae67.patch
Patch3:         Fix-some-minor-inconsistencies-in-LAPACKE_czgesvdq.patch
# PATCH-FIX-UPSTREAM -- https://github.com/Reference-LAPACK/lapack/commit/ea2a102d3827.patch
Patch4:         Avoid-out-of-bounds-accesses-in-complex-EIG-tests.patch
# PATCH-FIX-UPSTREAM -- https://github.com/Reference-LAPACK/lapack/commit/38f3eeee3108b18158409ca2a100e6fe03754781
Patch5:         Fix-out-of-bounds-read.patch
# PATCH-FIX-UPSTREAM
Patch6:         https://github.com/Reference-LAPACK/lapack/commit/87536aa3c8bb.patch#/Restore_missing_deprecated_prototypes.patch

BuildRequires:  gcc-fortran
BuildRequires:  python3-base
BuildRequires:  update-alternatives
Requires(pre):  update-alternatives

%description
LAPACK provides routines for solving systems of simultaneous linear
equations, least-squares solutions of linear systems of equations,
eigenvalue problems, and singular value problems. The associated matrix
factorizations (LU, Cholesky, QR, SVD, Schur, generalized Schur) are
also provided, as are related computations such as reordering of the
Schur factorizations and estimating condition numbers. Dense and banded
matrices are handled, but not general sparse matrices. In all areas,
similar functionality is provided for real and complex matrices, in
both single and double precision.

%package     -n liblapack3
Summary:        LAPACK Shared Library
Group:          Development/Libraries/Parallel
Requires(pre):  update-alternatives

%description -n liblapack3
LAPACK provides routines for solving systems of simultaneous linear
equations, least-squares solutions of linear systems of equations,
eigenvalue problems, and singular value problems. The associated matrix
factorizations (LU, Cholesky, QR, SVD, Schur, generalized Schur) are
also provided, as are related computations such as reordering of the
Schur factorizations and estimating condition numbers. Dense and banded
matrices are handled, but not general sparse matrices. In all areas,
similar functionality is provided for real and complex matrices, in
both single and double precision.

%package     -n libblas3
Summary:        BLAS Shared Library
Group:          Development/Libraries/Parallel
Requires(pre):  update-alternatives

%description -n libblas3
BLAS (Basic Linear Algebra Subprograms) is a standard library for
numerical algebra.  BLAS provides a number of basic algorithms for
linear algebra.

%package        devel
Summary:        Linear Algebra Package
Group:          Development/Libraries/Parallel
Requires:       blas-devel = %{version}
Requires:       liblapack3 = %{version}
Provides:       lapack = %{version}
Obsoletes:      lapack < %{version}

%description    devel
LAPACK provides routines for solving systems of simultaneous linear
equations, least-squares solutions of linear systems of equations,
eigenvalue problems, and singular value problems. The associated matrix
factorizations (LU, Cholesky, QR, SVD, Schur, generalized Schur) are
also provided, as are related computations such as reordering of the
Schur factorizations and estimating condition numbers. Dense and banded
matrices are handled, but not general sparse matrices. In all areas,
similar functionality is provided for real and complex matrices, in
both single and double precision.

%package        devel-static
Summary:        Linear Algebra Package - static libraries
Group:          Development/Libraries/Parallel
Requires:       lapack-devel = %{version}

%description    devel-static
LAPACK provides routines for solving systems of simultaneous linear
equations, least-squares solutions of linear systems of equations,
eigenvalue problems, and singular value problems. The associated matrix
factorizations (LU, Cholesky, QR, SVD, Schur, generalized Schur) are
also provided, as are related computations such as reordering of the
Schur factorizations and estimating condition numbers. Dense and banded
matrices are handled, but not general sparse matrices. In all areas,
similar functionality is provided for real and complex matrices, in
both single and double precision.

%package     -n blas-devel
Summary:        Basic Linear Algebra Subprograms
Group:          Development/Libraries/Parallel
Requires:       libblas3 = %{version}
Provides:       blas = %{version}
Obsoletes:      blas < %{version}

%description -n blas-devel
BLAS (Basic Linear Algebra Subprograms) is a standard library for
numerical algebra. BLAS provides a number of basic algorithms for
linear algebra. BLAS is fast and well-tested, was written in FORTRAN 77
and built with gfortran. BLAS manual pages are available in the
blas-man package.

%package     -n blas-devel-static
Summary:        Basic Linear Algebra Subprograms
Group:          Development/Libraries/Parallel
Requires:       blas-devel = %{version}

%description -n blas-devel-static
BLAS (Basic Linear Algebra Subprograms) is a standard library for
numerical algebra. BLAS provides a number of basic algorithms for
linear algebra. BLAS is fast and well-tested, was written in FORTRAN 77
and built with gfortran. BLAS manual pages are available in the
blas-man package.

%package     -n liblapacke3
Summary:        LAPACKE development files
Group:          Development/Libraries/C and C++
Requires(pre):  update-alternatives

%description -n liblapacke3
This library provides a native C interface to LAPACK routines available
at www.netlib.org/lapack to facilitate usage of LAPACK functionality
for C programmers.

This implementation introduces:
- row-major and column-major matrix layout controlled by the first function
  parameter;
- an implementation with working arrays (middle-level interface) as well as
  without working arrays (high-level interface);
- input scalars passed by value;
- error code as a return value instead of the INFO parameter.

%package     -n lapacke-devel
Summary:        LAPACKE development files
Group:          Development/Libraries/C and C++
Requires:       liblapacke3 = %{version}
Provides:       lapacke = %{version}

%description -n lapacke-devel
LAPACKE headers and development files.

%package     -n lapacke-devel-static
Summary:        LAPACKE static libraries
Group:          Development/Libraries/C and C++
Requires:       lapacke-devel = %{version}

%description -n lapacke-devel-static
LAPACKE development files - static libraries.

%package     -n libcblas3
Summary:        CBLAS Shared Library
Group:          Development/Libraries/C and C++
Requires(pre):  update-alternatives
# Only version ever packaged separately
Obsoletes:      libcblas3 == 20110120

%description -n libcblas3
This library provides a native C interface to BLAS routines available
at www.netlib.org/blas to facilitate usage of BLAS functionality
for C programmers.

%package     -n cblas-devel
Summary:        CBLAS development files
Group:          Development/Libraries/C and C++
Requires:       libcblas3 = %{version}
Provides:       cblas = %{version}

%description -n cblas-devel
cblas headers and development files.

%package     -n cblas-devel-static
Summary:        CBLAS - static libraries
Group:          Development/Libraries/C and C++
Requires:       cblas-devel = %{version}

%description -n cblas-devel-static
The cblas-devel-static package contains the CBLAS static libraries
for -static linking. You do not need these, unless you link
statically, which is highly discouraged.

%ifarch %{ix86}
%if 0%{?sle_version:%sle_version} >= 150000
%global precflags "-mfpmath=sse"
%global test_precflags %precflags
%else
%global test_precflags "-ffloat-store"
%endif
%endif

%prep
%setup -q
%autopatch -p1
sed -i -e '1 s@env python@python3@' lapack_testing.py

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%global optflags_f %{optflags}

cp make.inc.example make.inc
# for ABI compatibility we need to build the deprecated interfaces
echo 'BUILD_DEPRECATED = Yes' >> make.inc
%{?with_tmg:echo 'LAPACKE_WITH_TMG = Yes' >> make.inc}

%make_build cleanlib
%make_build blaslib \
  FFLAGS="%{optflags_f} %{?precflags} -fPIC"
mkdir tmp
( cd tmp; ar x ../librefblas.a )
gfortran -shared -Wl,-soname=libblas.so.3 -o libblas.so.%{version} -Wl,--no-undefined tmp/*.o
ln -s libblas.so.%{version} libblas.so
rm -rf tmp

%make_build cblaslib \
  CFLAGS="%{optflags} %{?precflags} -fPIC -DADD_ "
mkdir tmp
( cd tmp; ar x ../libcblas.a )
gfortran -shared -Wl,-soname=libcblas.so.3 -o libcblas.so.%{version} -Wl,--no-undefined tmp/*.o -L. -lblas
ln -s libcblas.so.%{version} libcblas.so
rm -rf tmp

# May need to be included in liblapack
%make_build -C TESTING/MATGEN FFLAGS="%{optflags_f} %{?test_precflags} %{?with_tmg:-fPIC}"

%make_build lapacklib \
  FFLAGS="%{optflags_f} %{?precflags} -fPIC"
mkdir tmp
( cd tmp; ar x ../liblapack.a; %{?with_tmg: ar x ../libtmglib.a; ar cr ../liblapack.a *.o; ranlib ../liblapack.a })
gfortran -shared -Wl,-soname=liblapack.so.3 -o liblapack.so.%{version} -Wl,--no-undefined tmp/*.o -L. -lblas
ln -s liblapack.so.%{version} liblapack.so
rm -rf tmp

make %{?_smp_mflags} lapackelib \
  CFLAGS="%{optflags}  %{?precflags} -fPIC -DADD_ -DHAVE_LAPACK_CONFIG_H -DLAPACK_COMPLEX_STRUCTURE"
mkdir tmp
( cd tmp; ar x ../liblapacke.a )
gfortran -shared -Wl,-soname=liblapacke.so.3 -o liblapacke.so.%{version} -Wl,--no-undefined tmp/*.o -L. -llapack
ln -s liblapacke.so.%{version} liblapacke.so
rm -rf tmp

# Build test binaries - blas
%make_build -C BLAS/TESTING FFLAGS="%{optflags_f} %{?test_precflags}"
# Build test binaries - cblas
%make_build -C CBLAS/testing FFLAGS="%{optflags_f} %{?test_precflags}"
# Build test binaries - lapack
%make_build -C TESTING/LIN FFLAGS="%{optflags_f} %{?test_precflags}"
%make_build -C TESTING/EIG FFLAGS="%{optflags_f} %{?test_precflags}"

%check
# Increase stack size, required for xeigtstz, see
# https://github.com/Reference-LAPACK/lapack/issues/335
# Remove for lapack > 3.9
ulimit -s 16384

%make_build blas_testing FFLAGS="%{optflags_f} %{?test_precflags}"
if grep -B15 -A15 FAIL BLAS/TESTING/*.out; then
  echo
  echo "blas_testing FAILED"
  false
fi

%make_build cblas_testing CFLAGS="%{optflags} -fPIC"
grep -B15 -A15 FAIL CBLAS/testing/*.out && false

%make_build lapack_testing FFLAGS="%{optflags_f} %{?test_precflags}"
if grep -B15 -A15 FAIL TESTING/*.out; then
  echo
  echo "lapack_testing FAILED"
  false
fi

%install
install -d %{buildroot}/%{_libdir}
install -d %{buildroot}/%{_sysconfdir}/alternatives
install -d %{buildroot}/%{_includedir}
## BLAS
install -d %{buildroot}/%{_libdir}/blas
install -m 644 librefblas.a %{buildroot}/%{_libdir}/libblas.a
install -m 755 libblas.so.%{version} %{buildroot}/%{_libdir}/blas
ln -s libblas.so.%{version} %{buildroot}/%{_libdir}/blas/libblas.so.3
ln -s blas/libblas.so.%{version} %{buildroot}/%{_libdir}/libblas.so
ln -s %{_sysconfdir}/alternatives/libblas.so.3%{?a_x} %{buildroot}/%{_libdir}/libblas.so.3
## CBLAS
install -m 644 CBLAS/include/*.h %{buildroot}/%{_includedir}
install -m 644 libcblas.a %{buildroot}/%{_libdir}
install -m 755 libcblas.so.%{version} %{buildroot}/%{_libdir}/blas
ln -s libcblas.so.%{version} %{buildroot}/%{_libdir}/blas/libcblas.so.3
ln -s blas/libcblas.so.%{version} %{buildroot}/%{_libdir}/libcblas.so
ln -s %{_sysconfdir}/alternatives/libcblas.so.3%{?a_x} %{buildroot}/%{_libdir}/libcblas.so.3
## LAPACK
install -d %{buildroot}/%{_libdir}/lapack
install -m 644 liblapack.a %{buildroot}/%{_libdir}
install -m 755 liblapack.so.%{version} %{buildroot}/%{_libdir}/lapack
ln -s liblapack.so.%{version} %{buildroot}/%{_libdir}/lapack/liblapack.so.3
ln -s lapack/liblapack.so.%{version} %{buildroot}/%{_libdir}/liblapack.so
ln -s %{_sysconfdir}/alternatives/liblapack.so.3%{?a_x} %{buildroot}/%{_libdir}/liblapack.so.3
## LAPACKE
install -m 644 LAPACKE/include/*.h %{buildroot}/%{_includedir}
install -m 644 liblapacke.a %{buildroot}/%{_libdir}
install -m 755 liblapacke.so.%{version} %{buildroot}/%{_libdir}/lapack
ln -s liblapacke.so.%{version} %{buildroot}/%{_libdir}/lapack/liblapacke.so.3
ln -s lapack/liblapacke.so.%{version} %{buildroot}/%{_libdir}/liblapacke.so
ln -s %{_sysconfdir}/alternatives/liblapacke.so.3%{?a_x} %{buildroot}/%{_libdir}/liblapacke.so.3

%post -n libblas3
%{_sbindir}/update-alternatives --install \
   %{_libdir}/libblas.so.3 libblas.so.3%{?a_x} %{_libdir}/blas/libblas.so.3  50
/sbin/ldconfig

%postun -n libblas3
/sbin/ldconfig
if [ ! %{_libdir}/blas/libblas.so.3 ] ; then
   %{_sbindir}/update-alternatives --remove libblas.so.3%{?a_x}  %{_libdir}/blas/libblas.so.3
fi

%post -n liblapack3
%{_sbindir}/update-alternatives --install \
   %{_libdir}/liblapack.so.3 liblapack.so.3%{?a_x} %{_libdir}/lapack/liblapack.so.3  50
/sbin/ldconfig

%postun -n liblapack3
/sbin/ldconfig
if [ ! -f  %{_libdir}/lapack/liblapack.so.3 ] ; then
   %{_sbindir}/update-alternatives --remove liblapack.so.3%{?a_x} %{_libdir}/lapack/liblapack.so.3
fi

%post -n libcblas3
%{_sbindir}/update-alternatives --install \
   %{_libdir}/libcblas.so.3 libcblas.so.3%{?a_x} %{_libdir}/blas/libcblas.so.3  50
/sbin/ldconfig

%postun -n libcblas3
/sbin/ldconfig
if [ ! -f %{_libdir}/blas/libcblas.so.3 ] ; then
   %{_sbindir}/update-alternatives --remove libcblas.so.3%{?a_x}  %{_libdir}/blas/libcblas.so.3
fi

%post -n liblapacke3
%{_sbindir}/update-alternatives --install \
   %{_libdir}/liblapacke.so.3 liblapacke.so.3%{?a_x} %{_libdir}/lapack/liblapacke.so.3  50
/sbin/ldconfig

%postun -n liblapacke3
/sbin/ldconfig
if [ ! -f %{_libdir}/lapack/liblapacke.so.3 ] ; then
   %{_sbindir}/update-alternatives --remove liblapacke.so.3%{?a_x} %{_libdir}/lapack/liblapacke.so.3
fi

%files -n liblapack3
%doc README.md
%license LICENSE
%dir %{_libdir}/lapack
%{_libdir}/lapack/liblapack.so.%{version}
%{_libdir}/lapack/liblapack.so.3
%ghost %{_libdir}/liblapack.so.3
%ghost %{_sysconfdir}/alternatives/liblapack.so.3%{?a_x}

%files -n libblas3
%doc README.md
%license LICENSE
%dir %{_libdir}/blas
%{_libdir}/blas/libblas.so.%{version}
%{_libdir}/blas/libblas.so.3
%ghost %{_libdir}/libblas.so.3
%ghost %{_sysconfdir}/alternatives/libblas.so.3%{?a_x}

%files devel
%{_libdir}/liblapack.so

%files devel-static
%{_libdir}/liblapack.a

%files -n blas-devel
%{_libdir}/libblas.so

%files -n blas-devel-static
%{_libdir}/libblas.a

%files -n liblapacke3
%{_libdir}/lapack/liblapacke.so.%{version}
%{_libdir}/lapack/liblapacke.so.3
%ghost %{_libdir}/liblapacke.so.3
%ghost %{_sysconfdir}/alternatives/liblapacke.so.3%{?a_x}

%files -n lapacke-devel
%doc LAPACKE/README
%license LAPACKE/LICENSE
%{_libdir}/liblapacke.so
%{_includedir}/lapack*.h

%files -n lapacke-devel-static
%{_libdir}/liblapacke.a

%files -n libcblas3
%doc README.md
%license LICENSE
%dir %{_libdir}/blas
%{_libdir}/blas/libcblas.so.%{version}
%{_libdir}/blas/libcblas.so.3
%ghost %{_libdir}/libcblas.so.3
%ghost %{_sysconfdir}/alternatives/libcblas.so.3%{?a_x}

%files -n cblas-devel
%doc CBLAS/README
%{_libdir}/libcblas.so
%{_includedir}/cblas*.h

%files -n cblas-devel-static
%{_libdir}/libcblas.a

%changelog
* Thu Feb 23 2023 eich@suse.com
- Set -mfpmath=sse for the entire build for ix86 platforms
  on SLE/Leap. Since we build for x86_64, we know that sse
  is available.
  This helps to avoid effects from excess precision that
  can be seen in the test suite.
  On Factory we leave -ffloat-store for the test suite
  only as this option comes at a performance penalty.
  We may see precision related issues in the test suite
  with future compilers regardless.
* Wed Feb 15 2023 eich@suse.com
- As a configurable option add tmglib code to the LAPACK librarly
  and enable TMG in LAPACKE as the header files provide its API
  (boo#1207989 & bsc#1087426).
- Fix update-alternatives for lapacke (bsc#1207358).
- Restore generic link for update-alternatives. This is usually
  set by the update-alternatives and it is '%%ghost'ed but rpmlint
  complains.
- Move update-alternatives --remove to %%%%postun to stop rpmlint
  from complaining.
- Removed useless - because never executed - %%%%postrans scriptlets.
- Added missing _%%%%{_arch} to update-alternative names.
- rpmlint complains anyway - this time about alternative-link-missing
  - as it does not understand the _%%%%{_arch} endings: muffle with
  rpmlintrc.
- Make arch-dependent generic names conditional.
* Fri Feb 10 2023 stefan.bruens@rwth-aachen.de
- Fix missing symbols for deprecated functions in LAPACK, add
  Restore_missing_deprecated_prototypes.patch
- Add -Wl,--no-undefined when creating shared libraries,
  to catch missing symbols during build
- Test fixes:
  * Build test binaries during %%build, run in %%check
  * Fix incorrect path for test output, to actually catch
    any test failures
- Spec file cleanup:
  * Do not rename blaslib, it is used for test binaries
  * Use same commands for building lapacke as for other libs
  * Remove unused FFLAGS_NOOP for test binaries
* Sun Feb  5 2023 eich@suse.com
- Remove unneeded links. These will be taken care of by the
  update-alternatives. This will bring this package in sync
  with openblas.
* Thu Feb  2 2023 rguenther@suse.com
- Build deprecated functions again to avoid breaking the ABI.
  (boo#1207989)
* Wed Jan 25 2023 eich@suse.com
- Make library links in the alternatives directory arch dependent.
  This avoids conflicts when both 32-bit and 64-bit versions are
  installed (boo#1207563).
* Tue Mar 15 2022 eich@suse.com
- Consolidate dummy links for update-alternatives bringing them
  in sync with openblas. Add alternatives for lapacke.
* Mon Jan  3 2022 rguenther@suse.com
- Add Fix-out-of-bounds-read.patch to fix out of bound reads when
  user input is not validated properly.  (bsc#1193562, CVE-2021-4048)
* Mon Jul 19 2021 ismail@i10z.com
- Rename conflicting MIN.3 and MAX.3 manpages into lapack-{MAX,MIN}.3
* Wed Jul 14 2021 dimstar@opensuse.org
- Do not create the dummy files in /etc/alternatives during
  %%install: managed by update-alternatives and packaged as ghost.
* Mon May 10 2021 dmueller@suse.com
- stop owning directories provided by filesystem (bsc#1184786)
* Mon Oct 12 2020 stefan.bruens@rwth-aachen.de
- Update to version 3.9.0:
  * LAPACK QR-preconditioned QR SVD method - xGESVDQ routines
  * LAPACK Householder Reconstruction
- Add Avoid-out-of-bounds-accesses-in-complex-EIG-tests.patch
- Rebase lapack-3.2.2.patch
- Drop -std=legacy from fortran flags:
  * add Fix-MinGW-build-error.patch
  * add Fix-some-minor-inconsistencies-in-LAPACKE_czgesvdq.patch
- Remove pre_checkin.sh, remove lapack-man.changes copy
* Fri Oct  9 2020 stefan.bruens@rwth-aachen.de
- Build CBLAS from lapack package
  * update baselibs.conf
- Clean up spec file:
  * remove useless make cleanlib
  * remove ineffective duplicated 'make ..lib' calls with deviating
    opts, as the object files are not removed (fortuanately) the
    existing PIC files are used for the static libraries
  * remove fortran-only -std=legacy opt from CFLAGS
* Fri Oct  9 2020 stefan.bruens@rwth-aachen.de
- lapack-man:
  * Build manpages from same sources as the binaries (3.8.0) instead
    of old 3.5.0.
  * Merge blas-man package into lapack-man package. Avoids tedious
    splitting of the two.
  * Use fdupes macro instead of trying to deduplicate man pages
    manually.
- Cleanup lapack spec:
  * Remove conditionals for obsolete distro versions
  * Only use python3-base instead of python3
  * Drop old copy of lapack_testing.py as separate source
* Fri Mar 13 2020 mliska@suse.cz
- Add -std=legacy in order to fix boo#1166619.
* Fri Aug  2 2019 mliska@suse.cz
- Use FAT LTO objects in order to provide proper static library.
* Thu Mar 29 2018 badshah400@gmail.com
- Update to version 3.8.0:
  * Symmetric-indefinite Factorization: Aasen’s tridiagonalization
    2 stage.
  * LAPACKE interfaces.
- Static -pic libraries are no longer built.
* Fri Jan 12 2018 rguenther@suse.com
- Package lapack_testing.py from lapack 3.8.0 with adjusted interpreter
  and adjust BuildRequires to python3.  [bnc#1075766]
* Wed May 31 2017 jengelh@inai.de
- Correct RPM groups
* Wed May 17 2017 dimstar@opensuse.org
- Build the man pages in a separate .spec file (lapack-man). The
  resulting rpm names are kept identical. This allows us to drop
  doxygen out of lapack's main package buildroot, thus eliminating
  a build cycle.
* Fri May  8 2015 dmitry_r@opensuse.org
- Fix static libraries list
* Wed Jul 16 2014 idonmez@suse.com
- Add baselibs.conf to sources
* Mon Jul 14 2014 toddrme2178@gmail.com
- Include update-alternatives dependency in subpackages that use it
  to guarantee it will be available.
* Wed Jun 18 2014 dmitry_r@opensuse.org
- Move blas and lapack libraries to subdirectories for fixing
  update-alternatives [bnc#861081]
- Add %%posttrans scripts for fixing migration problems.
* Thu Nov 21 2013 burnus@net-b.de
- Update to 3.5.0
  * Added Hermitian LDLT factorization routines with rook pivoting
    algorithm
  * 2-by-1 CSD to be used for tall and skinny matrix with orthonormal
    columns
  * New stopping criteria for balancing
  * New complex division algorithm
  * Various improvements
- No longer removing files due to license reasons as one file is
  no longer part of Lapack and the others have been replaced by
  new ones under the normal LAPACK license
* Tue Oct 29 2013 lnt-sysadmin@lists.lrz.de
- packaged symlinks created by update-alternative as %%ghost files
- removed quotes from update-alternative command to silence rpmlint warning
* Fri Mar 15 2013 dmitry_r@opensuse.org
- Split devel packages into devel and devel-static
* Sun Jan 13 2013 scorot@free.fr
- add update-alternative support to allow user to easily switch
  between several blas and lapack libraries
* Tue Nov  6 2012 burnus@net-b.de
- Update to 3.4.2
  * Bug fixes
* Wed Jul 25 2012 idonmez@suse.com
- Fix bnc#772628
* Thu Jul 19 2012 scorot@free.fr
- update baselibs.conf
* Sun Jul 15 2012 scorot@free.fr
- build the c interface lapacke
* Thu May 31 2012 kukuk@suse.de
- doxygen >= 1.7 is required for building docu
* Mon May 21 2012 saschpe@suse.de
- Change obsoletes '<=' for lapack and blas back to '<', there was a
  version update in between
- Remove psfig.tex (bnc#757332)
* Wed May  9 2012 coolo@suse.com
- fixing dependencies for devel-32bit
* Fri May  4 2012 burnus@net-b.de
- Update to 3.4.1
  * Bug fixes
* Mon Apr  2 2012 rguenther@suse.com
- Undo spec file obfuscation
* Fri Mar 30 2012 toddrme2178@gmail.com
- Fixed building on openSUSE 11.4 by fixing defattr
- Made the package groups consistent: Development/Libraries/Parallel
- Cleaned up spec file formatting
- Made all requires use the new package naming
* Wed Mar 14 2012 saschpe@suse.de
- Adhere to shared library policy, packages containing *.so or *.h
  files have to be named $FOO-devel, packages containing *.a files either
  have to be named $FOO-devel-static or provide this name
- Set license to 'BSD-3-Clause', according to the file LICENSE and the
  description on http://www.netlib.org/lapack/ it's not public domain
- Package README and LICENSE in library packages
- Removed rpmlint filters
- Use upstream tarball URL
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Nov 23 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Wed Nov 16 2011 burnus@net-b.de
- Update to 3.4.0
  * xGEQRT: QR factorization (improved interface)
  * xGEQRT3: recursive QR factorization.
  * xTPQRT: Communication-Avoiding QR sequential kernels.
  * Bug fixes.
  * Changes see http://www.netlib.org/lapack/lapack-3.4.0.html
* Fri Sep  9 2011 burnus@net-b.de
- Run BLAS and LAPACK testsuite when building
* Thu May 12 2011 burnus@net-b.de
- Update to 3.3.1 [bnc#654560]
  * New procedures to compute the complete CS decomposition of a
    partitioned unitary matrix
  * Level-3 BLAS symmetric indefinite solve (xSYTRS) and symmetric
    indefinite inversion (xSYTRI)
  * Bug fixes
  * Changes see at http://www.netlib.org/lapack/lapack-3.3.1.html
    and http://www.netlib.org/lapack/lapack-3.3.0.html
* Thu Aug 12 2010 rguenther@novell.com
- Add baselibs.  [bnc#630656]
* Thu Jul  8 2010 burnus@net-b.de
- Update to version 3.2.2
  * Bug fix release
  * Changes see at http://www.netlib.org/lapack/lapack-3.2.2.html
* Tue Feb  9 2010 prusnak@suse.cz
- package man and blas-man as noarch
* Wed Jan 13 2010 rguenther@suse.de
- Drop -O3 -funroll-all-loops compiler flags, build dcabs1.f with -O0.
  [bnc#569978]
* Mon May 18 2009 dominique-obs@leuenberger.net
- Update to version 3.2.1 [bnc#504669]
  * Changes see at http://www.netlib.org/lapack/lapack-3.2.1.html
* Wed Jan 28 2009 rguenther@suse.de
- Update to version 3.2.0.  [bnc#456384]
  * Extra Precise Iterative Refinement
  * XBLAS
  * Non-Negative Diagonals from Householder QR
  * High Performance QR and Householder Reflections on Low-Profile Matrices
  * New fast and accurate Jacobi SVD
  * Routines for Rectangular Full Packed format
  * Pivoted Cholesky
  * Mixed precision iterative refinement
  * Some new variants added for the one sided factorization
  * More robust DQDS algorithm
* Sun May 11 2008 lrupp@suse.de
- use versioned requires/obsoletes
- %%run_ldconfig is deprecated
- prefix the patch with the packagename
* Fri Apr 27 2007 rguenther@suse.de
- Update to version 3.1.1.  [#265999]
- Integrates 3.1.0 errata and missing blas routines.
- Provides better gfortran SECOND integration.
- Split shared libraries into their own versioned subpackage.
* Fri Jan 19 2007 rguenther@suse.de
- Include fixes for the 3.1.0 errata.
- Add missing CSROT, DROTM, DROTMG, DSDOT, SDSDOT, SROTM, SROTMG
  and ZDROT from blas distribution.  [#228824]
* Thu Dec 14 2006 rguenther@suse.de
- Restore missing so symlinks.
* Tue Nov 14 2006 rguenther@suse.de
- Update to version 3.1.0.
- Rename blasman to blas-man.
- Rename lapack-manpages to lapack-man.
* Tue Oct 31 2006 rguenther@suse.de
- Trim BuildRequires.
- Build and package -fPIC static library variants.  [#205310]
- Fix installing of the libblas.so symlink.
- Do not package the matrix testing setup library libtmglib.
- Do not package useless README file.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Fri Apr 22 2005 meissner@suse.de
- fixed all other instances of -fno-f2c, and g77 -> gfortran use.
* Thu Apr 21 2005 meissner@suse.de
- g77 -> gfortran, -fno-f2c is no more.
* Sat Jan 29 2005 nashif@suse.de
- Updated manpages (#48784)
* Thu Jan 20 2005 ro@suse.de
- remove BuildPrereq, BuildRequires is generated
* Thu Mar 18 2004 nashif@suse.de
- Fixed permission for manpages (#36340)
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Feb  3 2003 meissner@suse.de
- Use $RPM_OPT_FLAGS, so it builds on ppc64.
* Mon Aug 26 2002 nashif@suse.de
- Fixed manpage conflict
- correct library version
* Mon Jul  1 2002 ro@suse.de
- use -fPIC for all shared objects
- link liblapack with shared libblas (same reason)
* Thu May  2 2002 sf@suse.de
- fixed %%{_lib}-problems for x86_64
* Mon Sep 17 2001 nashif@suse.de
-  Fixed bug #9925, adding blas to required packages.
* Tue May  8 2001 nashif@suse.de
-  Fixed bug #6803
* Thu Feb  8 2001 sf@suse.de
- compile with '-01' for IA64 due to 'internal compiler error' in g77
* Mon Nov  6 2000 nashif@suse.de
-  Fixed bug of missing objects (#4028)
* Fri Apr 21 2000 nashif@suse.de
-  Applied new patches
-  Modified group, url and files in spec
* Mon Feb 21 2000 nashif@suse.de
-   Applied new patches
* Tue Jan 18 2000 nashif@suse.de
-   Applied new patched
-   Moved manpages to /usr/share/man
* Thu Dec 23 1999 nashif@suse.de
-    Update to latest version
-    Package split lapack + blas
* Thu Oct  7 1999 nashif@suse.de
- Package split: man pages + libraries
* Wed Sep 22 1999 nashif@suse.de
- New package: LAPACK
  Linear Algebra Package (LAPACK)
